USE IDENTIFIER(:database);
-- Insert sample inventory records for coffee pods
INSERT INTO inventory (
    -- Core identification
    inventory_id,
    product_id,
    
    -- Store information
    store_id,
    store_name,
    store_address,
    store_city,
    store_state,
    store_zip_code,
    store_phone,
    store_email,
    store_type,
    store_size_sqft,
    store_rating,
    store_hours,
    latitude,
    longitude,
    
    -- Inventory fields
    store,
    store_quantity,
    warehouse,
    warehouse_quantity,
    retail_amount,
    popularity_rating,
    department,
    aisle_location,
    is_closeout,
    
    -- Stock management
    min_stock_level,
    max_stock_level,
    last_restock_date,
    last_count_date,
    is_out_of_stock,
    is_low_stock,
    next_restock_date,
    
    -- Demand prediction
    daily_demand_prediction,
    weekly_demand_prediction,
    monthly_demand_prediction,
    last_7_days_sales,
    last_30_days_sales,
    last_90_days_sales,
    days_until_stockout,
    stockout_risk_level,
    
    -- Seasonality
    is_seasonal,
    season_peak_factor,
    trend_direction,
    trend_strength,
    
    -- Metadata
    last_prediction_update,
    is_store_active,
    store_created_at,
    store_last_updated
) VALUES
    -- Starbucks Pike Place Medium Roast K-Cups (Out of Stock at Downtown)
    (1001, 1, 
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 0, 'WH-NORTH', 150,
    18.99, 'high', 'Coffee & Tea', 'Aisle 3B', false,
    30, 120, '2024-03-01', '2024-03-15', true, false, '2024-03-20',
    15, 105, 450, 98, 392, 1176, 0, 'critical',
    false, 1.0, 'stable', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Peet's Coffee Major Dickason's Blend K-Cups (Alternative to Pike Place, In Stock at Downtown)
    (1002, 2,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 45, 'WH-NORTH', 200,
    17.99, 'high', 'Coffee & Tea', 'Aisle 3B', false,
    25, 100, '2024-03-10', '2024-03-15', false, false, null,
    12, 84, 360, 75, 300, 900, 4, 'low',
    false, 1.0, 'increasing', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Starbucks Pike Place Medium Roast K-Cups (In Stock at Marina)
    (1003, 1,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 35, 'WH-NORTH', 100,
    18.99, 'high', 'Coffee & Tea', 'Aisle 2A', false,
    20, 80, '2024-03-12', '2024-03-15', false, false, null,
    10, 70, 300, 65, 260, 780, 3, 'medium',
    false, 1.0, 'stable', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Dunkin' Original Blend Medium Roast K-Cups (In Stock at Downtown)
    (1004, 3,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 50, 'WH-NORTH', 180,
    16.99, 'high', 'Coffee & Tea', 'Aisle 3B', false,
    25, 100, '2024-03-13', '2024-03-15', false, false, null,
    11, 77, 330, 70, 280, 840, 5, 'low',
    false, 1.0, 'stable', 0.5,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Starbucks Pike Place Medium Roast K-Cups (In Stock at Mission)
    (1005, 1,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 40, 'WH-SOUTH', 120,
    18.99, 'high', 'Coffee & Tea', 'Aisle 4C', false,
    25, 100, '2024-03-14', '2024-03-15', false, false, null,
    12, 84, 360, 72, 288, 864, 4, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Green Mountain Coffee Breakfast Blend K-Cups (In Stock at Downtown)
    (1006, 4,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 30, 'WH-NORTH', 90,
    15.99, 'medium', 'Coffee & Tea', 'Aisle 3B', false,
    20, 80, '2024-03-12', '2024-03-15', false, true, '2024-03-21',
    8, 56, 240, 50, 200, 600, 4, 'medium',
    false, 1.0, 'stable', 0.4,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- The Original Donut Shop Regular Medium Roast K-Cups (In Stock at Downtown)
    (1007, 5,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 25, 'WH-NORTH', 75,
    16.99, 'medium', 'Coffee & Tea', 'Aisle 3B', false,
    20, 80, '2024-03-11', '2024-03-15', false, true, '2024-03-22',
    7, 49, 210, 45, 180, 540, 3, 'high',
    false, 1.0, 'decreasing', 0.3,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers (In Stock at Downtown)
    (2001, 6,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 24, 'WH-NORTH', 120,
    89.99, 'high', 'Footwear', 'Aisle 5A', false,
    12, 48, '2024-03-10', '2024-03-15', false, false, null,
    3, 21, 90, 18, 72, 216, 8, 'low',
    false, 1.0, 'increasing', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers (In Stock at Marina)
    (2002, 6,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 18, 'WH-NORTH', 80,
    89.99, 'high', 'Footwear', 'Aisle 3A', false,
    10, 40, '2024-03-12', '2024-03-15', false, false, null,
    2, 14, 60, 12, 48, 144, 9, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Nike Air Force 1 Low (In Stock at Downtown)
    (2003, 7,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 30, 'WH-NORTH', 150,
    109.99, 'high', 'Footwear', 'Aisle 5A', false,
    15, 60, '2024-03-11', '2024-03-15', false, false, null,
    4, 28, 120, 22, 88, 264, 7, 'low',
    false, 1.0, 'increasing', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Nike Air Force 1 Low (In Stock at Mission)
    (2004, 7,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 35, 'WH-SOUTH', 140,
    109.99, 'high', 'Footwear', 'Aisle 3A', false,
    15, 60, '2024-03-13', '2024-03-15', false, false, null,
    4, 28, 120, 20, 80, 240, 9, 'low',
    false, 1.0, 'stable', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers (Out of Stock at Mission with restock date)
    (2005, 6,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 0, 'WH-SOUTH', 45,
    89.99, 'high', 'Footwear', 'Aisle 3A', false,
    12, 48, '2024-02-28', '2024-03-15', true, false, '2024-03-25',
    3, 21, 90, 15, 60, 180, 0, 'critical',
    false, 1.0, 'stable', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Converse Chuck Taylor All Star (In Stock at Downtown)
    (2005, 8,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 36, 'WH-NORTH', 180,
    64.99, 'high', 'Footwear', 'Aisle 5B', false,
    18, 72, '2024-03-09', '2024-03-15', false, false, null,
    5, 35, 150, 28, 112, 336, 7, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Converse Chuck Taylor All Star (Low Stock at Marina)
    (2006, 8,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 8, 'WH-NORTH', 120,
    64.99, 'medium', 'Footwear', 'Aisle 3B', false,
    18, 72, '2024-03-08', '2024-03-15', false, true, '2024-03-18',
    4, 28, 120, 24, 96, 288, 2, 'high',
    false, 1.0, 'increasing', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Vans Old Skool (In Stock at Downtown)
    (2007, 9,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 20, 'WH-NORTH', 100,
    69.99, 'high', 'Footwear', 'Aisle 5B', false,
    15, 60, '2024-03-12', '2024-03-15', false, false, null,
    3, 21, 90, 16, 64, 192, 7, 'low',
    false, 1.0, 'increasing', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Vans Old Skool (In Stock at Mission)
    (2008, 9,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 25, 'WH-SOUTH', 80,
    69.99, 'high', 'Footwear', 'Aisle 6A', false,
    15, 60, '2024-03-14', '2024-03-15', false, false, null,
    3, 21, 90, 18, 72, 216, 8, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Puma Suede Classic (In Stock at Downtown)
    (2009, 10,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 16, 'WH-NORTH', 90,
    79.99, 'medium', 'Footwear', 'Aisle 5A', false,
    12, 48, '2024-03-11', '2024-03-15', false, true, '2024-03-19',
    2, 14, 60, 12, 48, 144, 8, 'medium',
    false, 1.0, 'stable', 0.5,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Puma Suede Classic (Out of Stock at Marina)
    (2010, 10,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 0, 'WH-NORTH', 60,
    79.99, 'medium', 'Footwear', 'Aisle 3A', false,
    12, 48, '2024-02-28', '2024-03-15', true, false, '2024-03-17',
    2, 14, 60, 14, 56, 168, 0, 'critical',
    false, 1.0, 'increasing', 0.9,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers - Black Color (Out of Stock at Downtown)
    (2011, 6,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 0, 'WH-NORTH', 30,
    89.99, 'high', 'Footwear', 'Aisle 5A', false,
    6, 24, '2024-02-28', '2024-03-15', true, false, '2024-03-18',
    3, 21, 90, 21, 84, 252, 0, 'critical',
    false, 1.0, 'increasing', 0.9,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers - Navy Color (In Stock at Downtown)
    (2012, 6,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 15, 'WH-NORTH', 45,
    89.99, 'high', 'Footwear', 'Aisle 5A', false,
    6, 24, '2024-03-12', '2024-03-15', false, false, null,
    2, 14, 60, 12, 48, 144, 7, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers - Grey Color (In Stock at Downtown)
    (2013, 6,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 9, 'WH-NORTH', 45,
    89.99, 'medium', 'Footwear', 'Aisle 5A', false,
    6, 24, '2024-03-10', '2024-03-15', false, true, '2024-03-19',
    2, 14, 60, 10, 40, 120, 4, 'medium',
    false, 1.0, 'stable', 0.5,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers - Black Color (In Stock at Marina)
    (2014, 6,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 12, 'WH-NORTH', 36,
    89.99, 'high', 'Footwear', 'Aisle 3A', false,
    6, 24, '2024-03-13', '2024-03-15', false, false, null,
    2, 14, 60, 8, 32, 96, 6, 'medium',
    false, 1.0, 'increasing', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Gazelle Sneakers - Black Color (In Stock at Mission)
    (2015, 6,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 18, 'WH-SOUTH', 54,
    89.99, 'high', 'Footwear', 'Aisle 6C', false,
    6, 24, '2024-03-14', '2024-03-15', false, false, null,
    2, 14, 60, 10, 40, 120, 9, 'low',
    false, 1.0, 'stable', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Samba Sneakers (In Stock at Downtown)
    (2016, 11,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 20, 'WH-NORTH', 100,
    94.99, 'high', 'Footwear', 'Aisle 5A', false,
    12, 48, '2024-03-11', '2024-03-15', false, false, null,
    3, 21, 90, 15, 60, 180, 7, 'low',
    false, 1.0, 'increasing', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Samba Sneakers (In Stock at Marina)
    (2017, 11,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 14, 'WH-NORTH', 70,
    94.99, 'high', 'Footwear', 'Aisle 3A', false,
    12, 48, '2024-03-12', '2024-03-15', false, false, null,
    2, 14, 60, 10, 40, 120, 7, 'low',
    false, 1.0, 'stable', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Stan Smith Sneakers (In Stock at Downtown)
    (2018, 12,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 28, 'WH-NORTH', 140,
    84.99, 'high', 'Footwear', 'Aisle 5A', false,
    15, 60, '2024-03-09', '2024-03-15', false, false, null,
    4, 28, 120, 20, 80, 240, 7, 'low',
    false, 1.0, 'increasing', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Stan Smith Sneakers (Low Stock at Mission)
    (2019, 12,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 8, 'WH-SOUTH', 80,
    84.99, 'medium', 'Footwear', 'Aisle 6C', false,
    15, 60, '2024-03-08', '2024-03-15', false, true, '2024-03-17',
    4, 28, 120, 24, 96, 288, 2, 'high',
    false, 1.0, 'increasing', 0.9,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Superstar Sneakers (In Stock at Downtown)
    (2020, 13,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 22, 'WH-NORTH', 110,
    99.99, 'high', 'Footwear', 'Aisle 5A', false,
    12, 48, '2024-03-13', '2024-03-15', false, false, null,
    3, 21, 90, 16, 64, 192, 7, 'low',
    false, 1.0, 'stable', 0.7,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Superstar Sneakers (In Stock at Marina)
    (2021, 13,
    102, 'Marina Market', '2200 Chestnut Street', 'San Francisco', 'CA', '94123',
    '415-555-0102', 'marina@market.com', 'express', 8000, 4.3,
    '{"monday": {"open": "08:00", "close": "21:00"}, "tuesday": {"open": "08:00", "close": "21:00"}, "wednesday": {"open": "08:00", "close": "21:00"}, "thursday": {"open": "08:00", "close": "21:00"}, "friday": {"open": "08:00", "close": "22:00"}, "saturday": {"open": "08:00", "close": "22:00"}, "sunday": {"open": "09:00", "close": "20:00"}}',
    37.8003, -122.4378,
    'SF-MARINA', 16, 'WH-NORTH', 80,
    99.99, 'high', 'Footwear', 'Aisle 3A', false,
    12, 48, '2024-03-11', '2024-03-15', false, false, null,
    2, 14, 60, 12, 48, 144, 8, 'low',
    false, 1.0, 'increasing', 0.6,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Campus Sneakers (In Stock at Downtown)
    (2022, 14,
    101, 'Downtown Market', '123 Market Street', 'San Francisco', 'CA', '94105',
    '415-555-0101', 'downtown@market.com', 'flagship', 12000, 4.5,
    '{"monday": {"open": "07:00", "close": "22:00"}, "tuesday": {"open": "07:00", "close": "22:00"}, "wednesday": {"open": "07:00", "close": "22:00"}, "thursday": {"open": "07:00", "close": "22:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "21:00"}}',
    37.7897, -122.3972,
    'SF-DOWNTOWN', 18, 'WH-NORTH', 90,
    87.99, 'medium', 'Footwear', 'Aisle 5B', false,
    12, 48, '2024-03-12', '2024-03-15', false, false, null,
    2, 14, 60, 12, 48, 144, 9, 'low',
    false, 1.0, 'stable', 0.5,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()),

    -- Adidas Campus Sneakers (Out of Stock at Mission)
    (2023, 14,
    103, 'Mission Market', '2128 Mission Street', 'San Francisco', 'CA', '94110',
    '415-555-0103', 'mission@market.com', 'flagship', 15000, 4.7,
    '{"monday": {"open": "07:00", "close": "23:00"}, "tuesday": {"open": "07:00", "close": "23:00"}, "wednesday": {"open": "07:00", "close": "23:00"}, "thursday": {"open": "07:00", "close": "23:00"}, "friday": {"open": "07:00", "close": "23:00"}, "saturday": {"open": "08:00", "close": "23:00"}, "sunday": {"open": "08:00", "close": "22:00"}}',
    37.7631, -122.4198,
    'SF-MISSION', 0, 'WH-SOUTH', 60,
    87.99, 'medium', 'Footwear', 'Aisle 6C', false,
    12, 48, '2024-02-25', '2024-03-15', true, false, '2024-03-20',
    2, 14, 60, 16, 64, 192, 0, 'critical',
    false, 1.0, 'increasing', 0.8,
    CURRENT_TIMESTAMP(), true, '2023-01-01', CURRENT_TIMESTAMP()); 